summaryrefslogtreecommitdiffstats
path: root/bin/reproducible_build.sh
diff options
context:
space:
mode:
authorHolger Levsen <holger@layer-acht.org>2017-06-12 22:43:07 +0200
committerHolger Levsen <holger@layer-acht.org>2017-06-16 16:28:34 +0200
commitfef02237f9f7aef649db16ba4162355f9a4deb2f (patch)
treef6d98b71946ee2544e15b7dfe6202268ffcd6a80 /bin/reproducible_build.sh
parentef7fe352e2bb940ac2495e1f303d5ca7c8385b38 (diff)
downloadjenkins.debian.net-fef02237f9f7aef649db16ba4162355f9a4deb2f.tar.xz
reproducible Debian: WIP for s#testing#stretch#g - see TODO4stretch_rename.txt for status
Signed-off-by: Holger Levsen <holger@layer-acht.org>
Diffstat (limited to 'bin/reproducible_build.sh')
-rwxr-xr-xbin/reproducible_build.sh10
1 files changed, 5 insertions, 5 deletions
diff --git a/bin/reproducible_build.sh b/bin/reproducible_build.sh
index 928580f6..5185a12a 100755
--- a/bin/reproducible_build.sh
+++ b/bin/reproducible_build.sh
@@ -133,7 +133,7 @@ update_db_and_html() {
local OLD_STATUS=$(query_db "SELECT status FROM results WHERE package_id='${SRCPKGID}'" || \
query_db "SELECT status FROM results WHERE package_id='${SRCPKGID}'")
# irc+mail notifications for changing status in unstable and experimental
- if [ "$SUITE" != "testing" ] ; then
+ if [ "$SUITE" != "stretch" ] ; then
if [ "${OLD_STATUS}" = "reproducible" ] && [ "$STATUS" != "depwait" ] && \
( [ "$STATUS" = "unreproducible" ] || [ "$STATUS" = "FTBFS" ] ) ; then
MESSAGE="${DEBIAN_URL}/${SUITE}/${ARCH}/${SRCPACKAGE} : reproducible ➤ ${STATUS}"
@@ -626,8 +626,8 @@ export LANG="C"
unset LC_ALL
export LANGUAGE="en_US:en"
EOF
- # build path is not yet varied on testing
- if [ "${SUITE}" != "testing" ]; then
+ # build path is not yet varied on stretch
+ if [ "${SUITE}" != "stretch" ]; then
echo "BUILDDIR=/build/1st" >> "$TMPCFG"
else
echo "BUILDDIR=/build" >> "$TMPCFG"
@@ -689,8 +689,8 @@ export LC_ALL="$locale.UTF-8"
export LANGUAGE="$locale:$language"
umask 0002
EOF
- # build path is not yet varied on testing
- if [ "${SUITE}" != "testing" ]; then
+ # build path is not yet varied on stretch
+ if [ "${SUITE}" != "stretch" ]; then
local src_dir_name="$(perl -mDpkg::Source::Package -e '$_ = Dpkg::Source::Package->new(filename => $ARGV[0])->get_basename; s/_/-/g; print' -- "${SRCPACKAGE}_${EVERSION}.dsc")"
echo "BUILDDIR=/build/$src_dir_name" >> "$TMPCFG"
echo "BUILDSUBDIR=2nd" >> "$TMPCFG"